pub struct WgpuDevice { /* private fields */ }Expand description
A single wgpu proof-of-space encoder (one GPU queue) plus the erasure coding used to encode records host-side.
Implementations
Sourceimpl WgpuDevice
impl WgpuDevice
Sourcepub fn new(
instance: GpuRecordsEncoderInstance,
erasure_coding: ErasureCoding,
) -> Self
pub fn new( instance: GpuRecordsEncoderInstance, erasure_coding: ErasureCoding, ) -> Self
Create a new device from an abundance proof encoder instance.
Sourcepub fn generate_and_encode_pospace(
&mut self,
seed: &PosSeed,
record: &mut Record,
encoded_chunks_used_output: impl ExactSizeIterator<Item = impl DerefMut<Target = bool>>,
) -> Result<(), String>
pub fn generate_and_encode_pospace( &mut self, seed: &PosSeed, record: &mut Record, encoded_chunks_used_output: impl ExactSizeIterator<Item = impl DerefMut<Target = bool>>, ) -> Result<(), String>
Generate proofs on the GPU and encode a record with subspace’s KZG scheme.
Mirrors record_encoding in subspace-farmer-components, so output is byte-identical to
the CPU encoder.